package cn.com.infosec.jce;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERConstructedSequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSet;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.exception.CertificateNotMatchException;
import cn.com.infosec.jce.exception.DecryptDataException;
import cn.com.infosec.jce.exception.DecryptKeyException;
import cn.com.infosec.jce.exception.EncryptAlgException;
import cn.com.infosec.jce.exception.EncryptDataException;
import cn.com.infosec.jce.exception.EncryptKeyException;
import cn.com.infosec.jce.exception.WriteEnvDataException;
import cn.com.infosec.jce.provider.InfosecProvider;
import cn.com.infosec.jce.provider.fastparser.DerUtil;
import cn.com.infosec.jce.provider.fastparser.EncryptedContentInfo;
import cn.com.infosec.jce.provider.fastparser.EnvelopedData;
import cn.com.infosec.jce.provider.fastparser.FastPkcs7;
import cn.com.infosec.jce.provider.fastparser.IssuerAndSerialNumber;
import cn.com.infosec.jce.provider.fastparser.Item;
import cn.com.infosec.jce.provider.fastparser.RecipientInfo;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintStream;
import java.security.KeyStore;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.Security;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.Enumeration;
import java.util.HashMap;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;

public class PKCS7EnvelopedData implements PKCSObjectIdentifiers {
   public static SecretKey key;
   public static final int TRIPLE_DES_CBC = 1;
   public static final int DES_CBC = 2;
   public static final int RC2_CBC = 3;
   static final int MD5 = 1;
   static final int MD2 = 2;
   static final int SHA1 = 3;
   static final int RSA = 4;
   static final int DSA = 5;
   static final int SHA224 = 6;
   static final int SHA256 = 7;
   static final int SHA384 = 8;
   static final int SHA512 = 9;
   static final int RC4 = 10;
   static final int DES = 11;
   static final int DESEDE = 12;
   static final int RC2 = 13;
   static final int AES = 14;
   public static final int IV_LENGTH = 8;
   private static final String OID_ENVELOPEDDATATYPE = "1.2.840.113549.1.7.3";
   private static final String OID_ENCRYPTCONTENT = "1.2.840.113549.1.7.1";
   private static final String OID_RSA_ECB_PKCS1PADDING = "1.2.840.113549.1.1.1";
   static final String ID_MD5 = "1.2.840.113549.2.5";
   static final String ID_MD2 = "1.2.840.113549.2.2";
   static final String ID_SHA1 = "1.3.14.3.2.26";
   static final String ID_RSA = "1.2.840.113549.1.1.1";
   static final String ID_DSA = "1.2.840.10040.4.1";
   static final String ID_SHA224 = "2.16.840.1.101.3.4.2.4";
   static final String ID_SHA256 = "2.16.840.1.101.3.4.2.1";
   static final String ID_SHA384 = "2.16.840.1.101.3.4.2.2";
   static final String ID_SHA512 = "2.16.840.1.101.3.4.2.3";
   static final String ID_RC4 = "1.2.840.113549.3.4";
   static final String ID_DES = "1.3.14.3.2.7";
   static final String ID_DESEDE = "1.2.840.113549.3.7";
   static final String ID_RC2 = "1.2.840.113549.3.2";
   static final String ID_AES = "2.16.840.1.101.3.4.2";
   static String[] algArray = new String[]{"MD5", "MD2", "SHA1", "RSA", "DSA", "SHA224", "SHA256", "SHA384", "SHA512", "RC4", "DES", "DESEDE", "RC2", "AES"};
   static String[] algArray2 = new String[]{"MD5", "MD2", "SHA1", "RSA", "DSA", "SHA224", "SHA256", "SHA384", "SHA512", "RC4", "DES", "3DES", "RC2", "AES"};
   static HashMap algmap;
   byte[] bsPKCS7;
   FastPkcs7 fxPKCS7;

   static {
      (algmap = new HashMap()).put("1.2.840.113549.2.5", "MD5");
      algmap.put("1.2.840.113549.2.2", "MD2");
      algmap.put("1.3.14.3.2.26", "SHA1");
      algmap.put("1.2.840.113549.1.1.1", "RSA");
      algmap.put("1.2.840.10040.4.1", "DSA");
      algmap.put("2.16.840.1.101.3.4.2.4", "SHA224");
      algmap.put("2.16.840.1.101.3.4.2.1", "SHA256");
      algmap.put("2.16.840.1.101.3.4.2.2", "SHA384");
      algmap.put("2.16.840.1.101.3.4.2.3", "SHA512");
      algmap.put("1.2.840.113549.3.4", "RC4");
      algmap.put("1.3.14.3.2.7", "DES");
      algmap.put("1.2.840.113549.3.7", "DESEDE");
      algmap.put("1.2.840.113549.3.2", "RC2");
      algmap.put("2.16.840.1.101.3.4.2", "AES");
   }

   public PKCS7EnvelopedData() {
      PKCS7EnvelopedData var10000 = this;
      super();
      this.bsPKCS7 = null;
      this.fxPKCS7 = null;
      FastPkcs7 var1;
      var1 = new FastPkcs7.<init>();
      var10000.fxPKCS7 = var1;
   }

   private static AlgorithmIdentifier getAlgorithmIdentifier(int alg) {
      String var1 = null;
      boolean var2 = false;
      if (alg == 10) {
         var1 = "1.2.840.113549.3.4";
         var2 = false;
      } else if (alg == 13) {
         var1 = "1.2.840.113549.3.2";
         var2 = true;
      } else if (alg == 12) {
         var1 = "1.2.840.113549.3.7";
         var2 = true;
      } else if (alg == 11) {
         var1 = "1.3.14.3.2.7";
         var2 = true;
      } else if (alg == 14) {
         var1 = "2.16.840.1.101.3.4.2";
         var2 = true;
      }

      DERObjectIdentifier alg1 = null;
      DEROctetString var5;
      if (var2) {
         byte[] alg2 = new byte[8];
         (new SecureRandom()).nextBytes(alg2);
         var5 = new DEROctetString.<init>(alg2);
      } else {
         var5 = alg1;
      }

      alg1 = new DERObjectIdentifier.<init>(var1);
      return new AlgorithmIdentifier(alg1, var5);
   }

   private static String getKeyGenAlgName(int alg) {
      String var1 = "";
      if (alg == 10) {
         var1 = "RC4";
      } else if (alg == 3) {
         var1 = "RC2";
      } else if (alg == 2) {
         var1 = "DES";
      } else if (alg == 1) {
         var1 = "DESEDE";
      }

      return var1;
   }

   private static String getAlgName(String oid) {
      String var1 = null;
      if (algmap.containsKey(oid)) {
         var1 = algmap.get(oid).toString();
      }

      return var1;
   }

   private static String getAlgName(int alg) {
      return algArray[alg - 1];
   }

   private static int getAlgID(String alg) {
      int var1 = 0;
      int var2 = algArray2.length;

      for(int var3 = 0; var3 < var2; ++var3) {
         if (alg.equalsIgnoreCase(algArray2[var3])) {
            var1 = var3 + 1;
            break;
         }
      }

      return var1;
   }

   public static void main(String[] args) {
      Security.addProvider(new InfosecProvider());

      Exception var10000;
      label166: {
         boolean var10001;
         PKCS7EnvelopedData var34;
         try {
            var34 = new PKCS7EnvelopedData;
         } catch (Exception var25) {
            var10000 = var25;
            var10001 = false;
            break label166;
         }

         PKCS7EnvelopedData args1 = var34;

         FileInputStream var35;
         try {
            var34.<init>();
            var35 = new FileInputStream;
         } catch (Exception var24) {
            var10000 = var24;
            var10001 = false;
            break label166;
         }

         FileInputStream var1 = var35;

         char[] var36;
         try {
            var35.<init>("d:\\ttt.pfx");
            var36 = new char[8];
         } catch (Exception var23) {
            var10000 = var23;
            var10001 = false;
            break label166;
         }

         char[] var37 = var36;
         char[] var10002 = var36;
         char[] var10003 = var36;
         char[] var10004 = var36;
         char[] var10005 = var36;
         char[] var10006 = var36;
         char[] var2;
         char[] var10007 = var2 = var36;

         KeyStore var38;
         try {
            var10007[0] = '1';
            var10006[1] = '1';
            var10005[2] = '1';
            var10004[3] = '1';
            var10003[4] = '1';
            var10002[5] = '1';
            var37[6] = '1';
            var36[7] = '1';
            var38 = KeyStore.getInstance("PKCS12", "INFOSEC");
         } catch (Exception var22) {
            var10000 = var22;
            var10001 = false;
            break label166;
         }

         KeyStore var3;
         KeyStore var40 = var3 = var38;

         Enumeration var42;
         try {
            var40.load(var1, var2);
            var42 = var38.aliases();
         } catch (Exception var21) {
            var10000 = var21;
            var10001 = false;
            break label166;
         }

         Enumeration var30 = var42;
         String var4 = null;

         label141:
         while(true) {
            boolean var45;
            try {
               var45 = var30.hasMoreElements();
            } catch (Exception var17) {
               var10000 = var17;
               var10001 = false;
               break;
            }

            String var46;
            if (!var45) {
               X509Certificate var39;
               try {
                  var38 = var3;
                  var46 = var4;
                  var1.close();
                  var39 = (X509Certificate)var3.getCertificate(var4);
               } catch (Exception var16) {
                  var10000 = var16;
                  var10001 = false;
                  break;
               }

               X509Certificate var28 = var39;

               try {
                  PrivateKey var47 = (PrivateKey)var38.getKey(var46, "".toCharArray());
               } catch (Exception var15) {
                  var10000 = var15;
                  var10001 = false;
                  break;
               }

               byte[] var48;
               try {
                  var48 = "This is a Test".getBytes();
               } catch (Exception var14) {
                  var10000 = var14;
                  var10001 = false;
                  break;
               }

               byte[] var31 = var48;

               long var50;
               try {
                  System.out.println("====================");
                  var50 = System.currentTimeMillis();
               } catch (Exception var13) {
                  var10000 = var13;
                  var10001 = false;
                  break;
               }

               long var32 = var50;
               byte[] var33 = null;

               for(int var6 = 0; var6 < 100; ++var6) {
                  try {
                     var48 = args1.encrypt(var31, var28, 10);
                  } catch (Exception var12) {
                     var10000 = var12;
                     var10001 = false;
                     break label141;
                  }

                  var33 = var48;
               }

               try {
                  var50 = System.currentTimeMillis();
               } catch (Exception var11) {
                  var10000 = var11;
                  var10001 = false;
                  break;
               }

               long var29 = var50;

               StringBuffer var49;
               PrintStream var52;
               try {
                  var52 = System.out;
                  var49 = new StringBuffer;
               } catch (Exception var10) {
                  var10000 = var10;
                  var10001 = false;
                  break;
               }

               StringBuffer args2 = var49;

               long var41;
               long var43;
               try {
                  var41 = var29;
                  var43 = var32;
                  args2.<init>("time=");
               } catch (Exception var9) {
                  var10000 = var9;
                  var10001 = false;
                  break;
               }

               var41 -= var43;

               FileOutputStream var53;
               try {
                  var52.println(var49.append(var41).toString());
                  var53 = new FileOutputStream;
               } catch (Exception var8) {
                  var10000 = var8;
                  var10001 = false;
                  break;
               }

               FileOutputStream var51 = var53;
               FileOutputStream var44 = var53;

               try {
                  var44.<init>("d:\\testenv.dat");
                  var51.write(var33);
                  var53.close();
                  return;
               } catch (Exception var7) {
                  var10000 = var7;
                  var10001 = false;
                  break;
               }
            }

            try {
               var38 = var3;
               var46 = (String)var30.nextElement();
            } catch (Exception var20) {
               var10000 = var20;
               var10001 = false;
               break;
            }

            String var5 = var46;

            try {
               var45 = var38.isKeyEntry(var46);
            } catch (Exception var19) {
               var10000 = var19;
               var10001 = false;
               break;
            }

            if (var45) {
               var4 = var5;
            }

            try {
               var3.isCertificateEntry(var5);
            } catch (Exception var18) {
               var10000 = var18;
               var10001 = false;
               break;
            }
         }
      }

      var10000.printStackTrace();
   }

   public static boolean compereDN(String DN1, String JKSDN) {
      if (DN1 != null && JKSDN != null) {
         if (DN1.equals(JKSDN)) {
            return true;
         } else {
            String[] JKSDN1;
            String var2 = (JKSDN1 = JKSDN.split(","))[0].trim();

            for(int var3 = 1; var3 <= JKSDN1.length - 1; ++var3) {
               var2 = var2 + "," + JKSDN1[var3].trim();
            }

            return DN1.equals(var2);
         }
      } else {
         return false;
      }
   }

   public byte[] decrypt(byte[] envelopeddata, Certificate cert, PrivateKey prik, String provider) {
      if (!this.fxPKCS7.pkcs7SignedData(envelopeddata)) {
         throw new SecurityException("can't decode PKCS7EnvlopedData object");
      } else {
         EnvelopedData var5;
         if ((var5 = this.fxPKCS7.getEnvelopedData()) != null) {
            RecipientInfo var18;
            Item var6 = (var18 = (RecipientInfo)var5.getVRecipientInfo().get(0)).getIssuerAndSerialNumber();
            IssuerAndSerialNumber var7;
            IssuerAndSerialNumber var10001 = var7 = new IssuerAndSerialNumber;
            var10001.<init>(envelopeddata, var6);
            Item var35 = var10001.getIssuer();
            byte[] var10002 = new byte[var35.length];
            byte[] var28 = DerUtil.getItemDataAndTag(envelopeddata, var35);
            ASN1InputStream var10000 = new ASN1InputStream;
            ASN1InputStream var36 = var10000;
            var10000.<init>(var28);
            String var29 = "";

            Exception var34;
            boolean var38;
            String var42;
            label110: {
               label118: {
                  ASN1Sequence var39;
                  try {
                     var39 = ASN1Sequence.getInstance(var36.readObject());
                  } catch (Exception var17) {
                     var34 = var17;
                     var38 = false;
                     break label118;
                  }

                  ASN1Sequence var8 = var39;

                  try {
                     var42 = (new X509Name(var8)).toString();
                  } catch (Exception var16) {
                     var34 = var16;
                     var38 = false;
                     break label118;
                  }

                  var29 = var42;

                  try {
                     var10000.close();
                     break label110;
                  } catch (Exception var15) {
                     var34 = var15;
                     var38 = false;
                  }
               }

               var34.printStackTrace();
            }

            String var37 = var29;
            Certificate var44 = cert;
            String cert1 = var7.getSerialNumber().getSerialNumber().toString(10);
            X509Certificate var30;
            var42 = (var30 = (X509Certificate)var44).getIssuerDN().toString();
            var29 = var30.getSerialNumber().toString(10);
            if (compereDN(var37, var42) && var29.equals(cert1)) {
               byte[] var19 = var18.getEncKey();
               EncryptedContentInfo cert2;
               var35 = (cert2 = var5.getEncryptedContentInfoObject()).getContentEncryptionAlgorithm();
               int var26;
               var28 = new byte[var26 = var35.length];
               System.arraycopy(envelopeddata, var35.offset, var28, 0, var26);
               var10000 = new ASN1InputStream(var28);
               String var27 = "";

               label93: {
                  try {
                     var37 = getAlgName(AlgorithmIdentifier.getInstance(var10000.readObject()).getObjectId().getId());
                  } catch (Exception var14) {
                     var14.printStackTrace();
                     break label93;
                  }

                  var27 = var37;
               }

               byte[] var40 = var28 = DerUtil.getItemDataAndTag(envelopeddata, cert2.getIvParameter());
               var7 = null;
               IvParameterSpec var33;
               if (var40.length == 0 || var28[0] == 5 && var28[1] == 0) {
                  var33 = var7;
               } else {
                  var40 = var28;
                  int var32;
                  byte[] var31 = new byte[var32 = var28[1] & 255];
                  System.arraycopy(var40, 2, var31, 0, var32);
                  var33 = new IvParameterSpec.<init>(var31);
               }

               var37 = var27;
               var42 = provider;
               var10002 = envelopeddata;
               Item var10003 = cert2.getEncryptedContent();
               int envelopeddata1;
               byte[] cert3 = new byte[envelopeddata1 = var10003.length];
               System.arraycopy(var10002, var10003.offset, cert3, 0, envelopeddata1);

               Exception var20;
               Cipher var41;
               label79: {
                  label120: {
                     try {
                        var41 = Cipher.getInstance("RSA/ECB/PKCS1Padding", provider);
                     } catch (Exception var13) {
                        var34 = var13;
                        var38 = false;
                        break label120;
                     }

                     Cipher var43 = var41;

                     try {
                        var43.init(2, prik);
                        var10002 = var41.doFinal(var19);
                        break label79;
                     } catch (Exception var12) {
                        var34 = var12;
                        var38 = false;
                     }
                  }

                  var20 = var34;
                  throw new DecryptKeyException(var20.getMessage());
               }

               var19 = var10002;

               label121: {
                  Cipher var46;
                  try {
                     var46 = Cipher.getInstance(var37, var42);
                  } catch (Exception var11) {
                     var34 = var11;
                     var38 = false;
                     break label121;
                  }

                  Cipher var47 = var46;

                  SecretKeySpec var45;
                  byte[] var48;
                  try {
                     var41 = var47;
                     var48 = cert3;
                     var45 = new SecretKeySpec;
                  } catch (Exception var10) {
                     var34 = var10;
                     var38 = false;
                     break label121;
                  }

                  SecretKeySpec envelopeddata2 = var45;

                  try {
                     var45.<init>(var19, var27);
                     var41.init(2, envelopeddata2, var33);
                     return var46.doFinal(var48);
                  } catch (Exception var9) {
                     var34 = var9;
                     var38 = false;
                  }
               }

               var20 = var34;
               throw new DecryptDataException(var20.getMessage());
            } else {
               throw new CertificateNotMatchException("Certification is not match");
            }
         } else {
            throw new SecurityException("Not a valid PKCS#7 envloped-data object - wrong header" + this.fxPKCS7.getContentType());
         }
      }
   }

   public byte[] decrypt(byte[] envelopeddata, Certificate cert, PrivateKey prik) {
      return this.decrypt(envelopeddata, cert, prik, "INFOSEC");
   }

   public byte[] encrypt(byte[] plaindata, Certificate cert, String algStr, String provider, PublicKey pubk) {
      int var18;
      int var10000 = var18 = getAlgID(algStr);
      System.out.println("alg is:" + var18);
      System.out.println("1111111111111111111111111111111111111111111");
      DERInteger algStr1;
      algStr1 = new DERInteger.<init>(0);
      DERInteger var6;
      var6 = new DERInteger.<init>(0);
      cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber var7;
      X509Certificate cert1;
      var7 = new cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber.<init>(new X509Name((cert1 = (X509Certificate)cert).getIssuerDN().toString()), new DERInteger(cert1.getSerialNumber()));
      AlgorithmIdentifier cert2;
      cert2 = new AlgorithmIdentifier.<init>(new DERObjectIdentifier("1.2.840.113549.1.1.1"), (DEREncodable)null);
      System.out.println("222222222222222222222222222222222222222222222");
      KeyGenerator var8 = null;

      label71: {
         KeyGenerator var37;
         try {
            var37 = KeyGenerator.getInstance(getAlgName(var10000), provider);
         } catch (NoSuchProviderException var16) {
            break label71;
         } catch (NoSuchAlgorithmException var17) {
            throw new EncryptAlgException("AlgException");
         }

         var8 = var37;
      }

      System.out.println("333333333333333333333333333333333333333333333333");
      SecretKey var34;
      SecretKey var10001 = var34 = var8.generateKey();
      System.out.println("444444444444444444444444444444444444444444444444");
      byte[] var9 = var10001.getEncoded();
      System.out.println("5555555555555555555555555555555555555555555555555");

      boolean var39;
      Cipher var41;
      try {
         var41 = Cipher.getInstance("RSA/ECB/PKCS1Padding", provider);
      } catch (Exception var15) {
         var39 = false;
         throw new EncryptKeyException("enc key exception");
      }

      Cipher var10002 = var41;

      byte[] var44;
      try {
         var10002.init(1, pubk);
         var44 = var41.doFinal(var9);
      } catch (Exception var14) {
         var39 = false;
         throw new EncryptKeyException("enc key exception");
      }

      byte[] pubk1 = var44;
      System.out.println("6666666666666666666666666666666666666666666666666");
      DEROctetString var35;
      var35 = new DEROctetString.<init>(pubk1);
      DERConstructedSequence pubk2;
      DERConstructedSequence var47 = pubk2 = new DERConstructedSequence;
      pubk2.<init>();
      pubk2.addObject(var6);
      pubk2.addObject(var7);
      pubk2.addObject(cert2);
      var47.addObject(var35);
      System.out.println("77777777777777777777777777777777777777777777777777");
      DERSet cert3;
      cert3 = new DERSet.<init>(pubk2);
      DERObjectIdentifier pubk3;
      pubk3 = new DERObjectIdentifier.<init>("1.2.840.113549.1.7.1");
      AlgorithmIdentifier var32;
      DERObject var33;
      DERObject var38 = var33 = (DERObject)(var32 = getAlgorithmIdentifier(var18)).getParameters();
      IvParameterSpec var36 = null;
      if (var38 != null) {
         var36 = new IvParameterSpec.<init>(((DEROctetString)var33).getOctets());
      }

      var10000 = var18;
      System.out.println("888888888888888888888888888888888888888888888888888");

      Cipher var40;
      try {
         var40 = Cipher.getInstance(getAlgName(var10000), provider);
      } catch (Exception var13) {
         var39 = false;
         throw new EncryptDataException("encrypt data error");
      }

      var41 = var40;

      byte[] var42;
      try {
         var41.init(1, var34, var36);
         var42 = var40.doFinal(plaindata);
      } catch (Exception var12) {
         var39 = false;
         throw new EncryptDataException("encrypt data error");
      }

      byte[] var19 = var42;
      System.out.println("9999999999999999999999999999999999999999999999999999");
      DERTaggedObject plaindata1;
      DERTaggedObject var43 = plaindata1 = new DERTaggedObject;
      DEROctetString provider1;
      provider1 = new DEROctetString.<init>(var19);
      var43.<init>(true, 0, provider1);
      DERConstructedSequence var20;
      DERConstructedSequence var45 = var20 = new DERConstructedSequence;
      var20.<init>();
      var20.addObject(pubk3);
      var20.addObject(var32);
      var45.addObject(plaindata1);
      DERConstructedSequence plaindata2;
      var45 = plaindata2 = new DERConstructedSequence;
      plaindata2.<init>();
      plaindata2.addObject(algStr1);
      plaindata2.addObject(cert3);
      var45.addObject(var20);
      var45 = var20 = new DERConstructedSequence;
      var45.<init>();
      var45.addObject(new DERObjectIdentifier("1.2.840.113549.1.7.3"));
      var45.addObject(new DERTaggedObject(true, 0, plaindata2));
      System.out.println("00000000000000000000000000000000000000000000000000");
      ByteArrayOutputStream plaindata3;
      ByteArrayOutputStream var48 = plaindata3 = new ByteArrayOutputStream;
      var48.<init>();
      DERConstructedSequence var10003 = var20;
      DEROutputStream var46 = new DEROutputStream(plaindata3);

      try {
         var46.writeObject(var10003);
      } catch (IOException var11) {
         throw new WriteEnvDataException("write Envelop Data Error!");
      }

      var19 = var48.toByteArray();

      try {
         var48.close();
      } catch (IOException var10) {
      }

      return var19;
   }

   public byte[] encrypt(byte[] plaindata, Certificate cert, String algStr, String provider) {
      int var18;
      int var10000 = var18 = getAlgID(algStr);
      DERInteger algStr1;
      algStr1 = new DERInteger.<init>(0);
      DERInteger var5;
      var5 = new DERInteger.<init>(0);
      cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber var6;
      X509Certificate var7;
      var6 = new cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber.<init>(new X509Name((var7 = (X509Certificate)cert).getIssuerDN().toString()), new DERInteger(var7.getSerialNumber()));
      AlgorithmIdentifier var29;
      var29 = new AlgorithmIdentifier.<init>(new DERObjectIdentifier("1.2.840.113549.1.1.1"), (DEREncodable)null);
      KeyGenerator var8 = null;

      label69: {
         KeyGenerator var35;
         try {
            var35 = KeyGenerator.getInstance(getKeyGenAlgName(var10000), provider);
         } catch (NoSuchProviderException var16) {
            break label69;
         } catch (NoSuchAlgorithmException var17) {
            throw new EncryptAlgException("AlgException");
         }

         var8 = var35;
      }

      Certificate var10001 = cert;
      SecretKey cert1;
      byte[] var30 = (cert1 = var8.generateKey()).getEncoded();
      PublicKey var9 = var10001.getPublicKey();

      boolean var38;
      Cipher var40;
      try {
         var40 = Cipher.getInstance("RSA/ECB/PKCS1Padding", provider);
      } catch (Exception var15) {
         var38 = false;
         throw new EncryptKeyException("enc key exception");
      }

      Cipher var10002 = var40;

      byte[] var43;
      try {
         var10002.init(1, var9);
         var43 = var40.doFinal(var30);
      } catch (Exception var14) {
         var38 = false;
         throw new EncryptKeyException("enc key exception");
      }

      var30 = var43;
      DEROctetString var31;
      var31 = new DEROctetString.<init>(var30);
      DERConstructedSequence var32;
      DERConstructedSequence var45 = var32 = new DERConstructedSequence;
      var32.<init>();
      var32.addObject(var5);
      var32.addObject(var6);
      var32.addObject(var29);
      var45.addObject(var31);
      DERSet var27;
      var27 = new DERSet.<init>(var32);
      DERObjectIdentifier var28;
      var28 = new DERObjectIdentifier.<init>("1.2.840.113549.1.7.1");
      DERObject var34;
      DERObject var36 = var34 = (DERObject)(var29 = getAlgorithmIdentifier(var18)).getParameters();
      IvParameterSpec var33 = null;
      if (var36 != null) {
         var33 = new IvParameterSpec.<init>(((DEROctetString)var34).getOctets());
      }

      Cipher var37;
      try {
         var37 = Cipher.getInstance(getAlgName(var18), provider);
      } catch (Exception var13) {
         var38 = false;
         throw new EncryptDataException("encrypt data error");
      }

      var40 = var37;

      byte[] var39;
      try {
         var40.init(1, cert1, var33);
         var39 = var37.doFinal(plaindata);
      } catch (Exception var12) {
         var38 = false;
         throw new EncryptDataException("encrypt data error");
      }

      byte[] var19 = var39;
      DERTaggedObject plaindata1;
      DERTaggedObject var41 = plaindata1 = new DERTaggedObject;
      DEROctetString cert2;
      cert2 = new DEROctetString.<init>(var19);
      var41.<init>(true, 0, cert2);
      DERConstructedSequence var20;
      DERConstructedSequence var42 = var20 = new DERConstructedSequence;
      var20.<init>();
      var20.addObject(var28);
      var20.addObject(var29);
      var42.addObject(plaindata1);
      DERConstructedSequence plaindata2;
      var42 = plaindata2 = new DERConstructedSequence;
      plaindata2.<init>();
      plaindata2.addObject(algStr1);
      plaindata2.addObject(var27);
      var42.addObject(var20);
      var42 = var20 = new DERConstructedSequence;
      var42.<init>();
      var42.addObject(new DERObjectIdentifier("1.2.840.113549.1.7.3"));
      var42.addObject(new DERTaggedObject(true, 0, plaindata2));
      ByteArrayOutputStream plaindata3;
      ByteArrayOutputStream var46 = plaindata3 = new ByteArrayOutputStream;
      var46.<init>();
      DERConstructedSequence var10003 = var20;
      DEROutputStream var44 = new DEROutputStream(plaindata3);

      try {
         var44.writeObject(var10003);
      } catch (IOException var11) {
         throw new WriteEnvDataException("write Envelop Data Error!");
      }

      var19 = var46.toByteArray();

      try {
         var46.close();
      } catch (IOException var10) {
      }

      return var19;
   }

   public byte[] encrypt(byte[] plaindata, Certificate cert, String algStr) {
      return this.encrypt(plaindata, cert, algStr, "INFOSEC");
   }

   public byte[] encrypt(byte[] plaindata, Certificate cert, int alg) {
      int var10000 = alg;
      DERInteger var17;
      var17 = new DERInteger.<init>(0);
      DERInteger var4;
      var4 = new DERInteger.<init>(0);
      cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber var5;
      X509Certificate var6;
      var5 = new cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber.<init>(new X509Name((var6 = (X509Certificate)cert).getIssuerDN().toString()), new DERInteger(var6.getSerialNumber()));
      AlgorithmIdentifier var28;
      var28 = new AlgorithmIdentifier.<init>(new DERObjectIdentifier("1.2.840.113549.1.1.1"), (DEREncodable)null);
      KeyGenerator var7 = null;

      label69: {
         KeyGenerator var34;
         try {
            var34 = KeyGenerator.getInstance(getKeyGenAlgName(var10000), "INFOSEC");
         } catch (NoSuchProviderException var15) {
            break label69;
         } catch (NoSuchAlgorithmException var16) {
            throw new EncryptAlgException("AlgException");
         }

         var7 = var34;
      }

      Certificate var10001 = cert;
      SecretKey cert1;
      byte[] var29 = (cert1 = var7.generateKey()).getEncoded();
      PublicKey var8 = var10001.getPublicKey();

      boolean var37;
      Cipher var39;
      try {
         var39 = Cipher.getInstance("RSA/ECB/PKCS1Padding", "INFOSEC");
      } catch (Exception var14) {
         var37 = false;
         throw new EncryptKeyException("enc key exception");
      }

      Cipher var10002 = var39;

      byte[] var42;
      try {
         var10002.init(1, var8);
         var42 = var39.doFinal(var29);
      } catch (Exception var13) {
         var37 = false;
         throw new EncryptKeyException("enc key exception");
      }

      var29 = var42;
      DEROctetString var30;
      var30 = new DEROctetString.<init>(var29);
      DERConstructedSequence var31;
      DERConstructedSequence var44 = var31 = new DERConstructedSequence;
      var31.<init>();
      var31.addObject(var4);
      var31.addObject(var5);
      var31.addObject(var28);
      var44.addObject(var30);
      DERSet var26;
      var26 = new DERSet.<init>(var31);
      DERObjectIdentifier var27;
      var27 = new DERObjectIdentifier.<init>("1.2.840.113549.1.7.1");
      DERObject var33;
      DERObject var35 = var33 = (DERObject)(var28 = getAlgorithmIdentifier(alg)).getParameters();
      IvParameterSpec var32 = null;
      if (var35 != null) {
         var32 = new IvParameterSpec.<init>(((DEROctetString)var33).getOctets());
      }

      Cipher var36;
      try {
         var36 = Cipher.getInstance(getAlgName(alg), "INFOSEC");
      } catch (Exception var12) {
         var37 = false;
         throw new EncryptDataException("encrypt data error");
      }

      var39 = var36;

      byte[] var38;
      try {
         var39.init(1, cert1, var32);
         var38 = var36.doFinal(plaindata);
      } catch (Exception var11) {
         var37 = false;
         throw new EncryptDataException("encrypt data error");
      }

      plaindata = var38;
      DERTaggedObject cert2;
      DERTaggedObject var40 = cert2 = new DERTaggedObject;
      DEROctetString alg1;
      alg1 = new DEROctetString.<init>(plaindata);
      var40.<init>(true, 0, alg1);
      DERConstructedSequence plaindata1;
      DERConstructedSequence var41 = plaindata1 = new DERConstructedSequence;
      plaindata1.<init>();
      plaindata1.addObject(var27);
      plaindata1.addObject(var28);
      var41.addObject(cert2);
      DERConstructedSequence cert3;
      var41 = cert3 = new DERConstructedSequence;
      cert3.<init>();
      cert3.addObject(var17);
      cert3.addObject(var26);
      var41.addObject(plaindata1);
      DERConstructedSequence var18;
      var41 = var18 = new DERConstructedSequence;
      var41.<init>();
      var41.addObject(new DERObjectIdentifier("1.2.840.113549.1.7.3"));
      var41.addObject(new DERTaggedObject(true, 0, cert3));
      ByteArrayOutputStream plaindata2;
      ByteArrayOutputStream var45 = plaindata2 = new ByteArrayOutputStream;
      var45.<init>();
      DERConstructedSequence var10003 = var18;
      DEROutputStream var43 = new DEROutputStream(plaindata2);

      try {
         var43.writeObject(var10003);
      } catch (IOException var10) {
         throw new WriteEnvDataException("write Envelop Data Error!");
      }

      byte[] var19 = var45.toByteArray();

      try {
         var45.close();
      } catch (IOException var9) {
      }

      return var19;
   }
}
